/*
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *     http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.hobsoft.symmetry.ui.binding;

import java.util.List;

import org.hobsoft.entangle.Observable;
import org.hobsoft.entangle.Observables;
import org.hobsoft.symmetry.ui.ListBox;
import org.hobsoft.symmetry.ui.binding.SymmetryObservables.ListBoxObservables;

/**
 * Default {@code ListBoxObservables} implementation.
 * 
 * @author Mark Hobson
 * @param <T>
 *            the item type
 * @see ListBoxObservables
 */
class DefaultListBoxObservables<T> extends DefaultComboBoxObservables<T> implements ListBoxObservables<T>
{
	// constructors -----------------------------------------------------------
	
	public DefaultListBoxObservables(ListBox<T> listBox)
	{
		super(listBox);
	}
	
	// ListBoxObservables methods ---------------------------------------------
	
	/**
	 * {@inheritDoc}
	 */
	@Override
	public Observable<int[]> selectedIndexes()
	{
		return Observables.bean(getComponent()).property(ListBox.SELECTED_INDEXES_PROPERTY, int[].class);
	}
	
	/**
	 * {@inheritDoc}
	 */
	@Override
	public Observable<List<T>> selectedItems()
	{
		return new ListBoxSelectedItemsObservable<T>(getComponent());
	}
	
	// DefaultComponentObservables methods ------------------------------------
	
	/**
	 * {@inheritDoc}
	 */
	@Override
	public ListBox<T> getComponent()
	{
		return (ListBox<T>) super.getComponent();
	}
}
